Crate open_gpui_refineable
open_
gpui_
refineable
0.1.0
All Items
Crate Items
Structs
Traits
Derive Macros
Crate
open_
gpui_
refineable
Structs

Cascade
A cascade of refinements that can be merged in priority order.
Cascade
Slot
A handle to a specific slot in a cascade.
Traits

IsEmpty
Refineable
A trait for types that can be refined with partial updates.
Derive Macros

Refineable